@@ -1,11 +1,10 @@
 package CPAN::Nearest;
-use Text::Fuzzy '0.15';
 require Exporter;
 @ISA = qw(Exporter);
 @EXPORT_OK = qw/search/;
 use warnings;
 use strict;
-our $VERSION = '0.09_02';
+our $VERSION = 0.01;
 use XSLoader;
 XSLoader::load 'CPAN::Nearest', $VERSION;
 
